@@ -5,8 +5,10 @@ from fsociety.core.menu import confirm
 
 
 class cuteitRepo(GitHubRepo):
-    def __init__(self, path="D4Vinci/Cuteit", install=None):
-        super().__init__(path=path, install=install)
+    def __init__(self):
+        super().__init__(path="D4Vinci/Cuteit", 
+                         install=None,
+                         description="IP obfuscator made to make a malicious ip a bit cuter")
 
     def run(self):
         os.chdir(self.full_path)
